# Files

Files generated by SOXSPIPE follow a [strict naming scheme](../soxs_file_naming_scheme.md).

## Product Files



## Static Calibration Files

```eval_rst
.. toctree::
   :maxdepth: 4

   pinhole_map
   detector_parameters
   spectral_format_table
```

## Intermediate Files

```eval_rst
.. toctree::
   :maxdepth: 4

   master_bias
   master_dark
   prepared_frame
   dispersion_map
   order_table
```
